function q = quality( varargin )
% QUALITY constructor function for QUALITY object
%
% Use:                 q = quality( <file> )
%
% by default:          q = quality 
% use @quality/quality.scv file
%
% example:
%   Get all types        get(q)
%   get internal has     get(q, 'NO_CONTROL')
%   get specific value   get(q, 'NO_CONTROL','code')
%  
% $Id$

switch nargin
  case 0  % create default object
    file = 'quality.csv';
  case 1
    if( isa(varargin{1}, 'char'))
      file = varargin{1};      
    else
      error('Wrong input argument');
    end
  otherwise
    error('Wrong number of input arguments');
end

if exist(file, 'file') ~= 2
  disp(['The specified data file ' file  ' does not exist ...']);
  disp('Or is not in the directory which is on the MATLAB search path');
  datagui_closereq_callback;
end

[type,label,code,color,state] = textread(...
      file,'%s%s%d%s%s','delimiter',';');

q.file = which(file);
q.size = length(type);
types   = hashtable;

for i=1:length(type)
  s.label  = label{i};
  s.code   = code(i);
  s.color  = color{i};
  s.state  = state{i};
 
  types = put(types, type{i}, s);
end	

q = class(q, 'quality', types );
